@@ -1,10 +1,11 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
   code based on calligra autocorrection.
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -765,7 +766,7 @@ bool AutoCorrection::excludeToUppercase(const QString &word) const
     return false;
 }
 
-void AutoCorrection::setNonBreakingSpace(const QChar &nonBreakingSpace)
+void AutoCorrection::setNonBreakingSpace(QChar nonBreakingSpace)
 {
     mNonBreakingSpace = nonBreakingSpace;
 }
