@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 #define CUSTOMTOOLSPLUGINMANAGER_H
 
 #include <QObject>
-#include "pimcommon_private_export.h"
+#include "pimcommon_export.h"
 namespace PimCommon {
 class CustomToolsPlugin;
 class CustomToolsPluginManagerPrivate;
-class PIMCOMMON_TESTS_EXPORT CustomToolsPluginManager : public QObject
+class PIMCOMMON_EXPORT CustomToolsPluginManager : public QObject
 {
     Q_OBJECT
 public:
